use strict;
use Test::More;
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Database::API::Connection qw( ConnectTestSite DisconnectSite );
use DE_EPAGES::Object::API::Factory qw (ExistsObjectByPath LoadRootObject LoadObjectByPath);
use DE_EPAGES::Object::API::XML::ObjectImportHandler qw (ImportObjects);
use DE_EPAGES::WebInterface::API::FakeRequest;

my $ROOTPATH = '/Test';
local $ENV{'EPAGES_TESTSITE'} = 'Store' unless defined $ENV{'EPAGES_TESTSITE'};

sub Main() {
    ConnectTestSite();
    ok( Init(),    'initialization' );
    ok( Tests(),   'tests' );
    ok( Cleanup(), 'cleanup' );
    DisconnectSite();
    done_testing();
}

sub Tests {
    my $Shop     = LoadObjectByPath($ROOTPATH)->child('TestShop');
    my $Category = $Shop->child('Categories');
    testCategoryPathDepth($Category, 0);
    $Category = $Category->child('MinimalCategory');
    testCategoryPathDepth($Category, 1);
    $Category = $Category->insertChild( 'Category', { 'Alias' => 'Test/AB' } );
    testCategoryPathDepth($Category, 2);
    return 1;
}

sub testCategoryPathDepth {
    my ($Category, $Depth) = @_;
    is($Category->get('CategoryPathDepth'), $Depth, $Category->pathString . ': CategoryPathDepth='.$Depth);
}

sub Init() {
    return 1 if LoadRootObject()->existsChild('Test') && $ENV{'SKIP_CLEANUP'};
    Cleanup();
    LoadRootObject()->insertChild( 'Object', { 'Alias' => 'Test' } );
    ImportObjects( 'import.xml', $ROOTPATH );
    return 1;
}

sub Cleanup() {
    return 1 if $ENV{'SKIP_CLEANUP'};
    LoadObjectByPath($ROOTPATH)->delete if ExistsObjectByPath($ROOTPATH);
    return 1;
}

RunScript( Sub => \&Main, Debug => 1 );
