use strict;
use DE_EPAGES::ClickAndBuy::API::XML::MMSHandler;
use DE_EPAGES::Core::API::Error qw ( ExistsError GetError );
use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Database::API::Connection qw ( RunOnStore );
use DE_EPAGES::Object::API::Factory qw (
    ExistsObjectByPath
    LoadObjectByGUID
    LoadObjectByPath
    LoadRootObject
);
use DE_EPAGES::Object::API::XML::ObjectImportHandler qw ( ImportObjects );
use Readonly;
use Test::More;

Readonly my $ROOTPATH => '/Test';

sub Main {
    RunOnStore(
        'Store' => 'Store',
        'Sub'   => sub {

            # startUp
            ok( Init(), 'initialization' );

            # tests
            eval {
                my $MMSHandler = DE_EPAGES::ClickAndBuy::API::XML::MMSHandler->new(getMMSXML());

                $MMSHandler->Handle( LoadObjectByPath($ROOTPATH.'/TestShop') );## no critic (ProhibitPathConcatenation)

                my $PLI = LoadObjectByGUID('50FFE7A2-8FF8-9E24-95C6-AC1532012147');## no critic (ProhibitPathConcatenation)
                is($PLI->get('TransStatus'), 'SUCCESS', 'MMS Handle')
            };

            if ( ExistsError() ) {
                my $Error = GetError();
                fail( 'Error: ' . $Error->longMessage );
            }

            # shutDown
            ok( Cleanup(), 'cleanup' );
            done_testing();
        }
    );
}

sub Cleanup {
    return 1 if $ENV{'SKIP_CLEANUP'};
    LoadObjectByPath($ROOTPATH)->delete if ExistsObjectByPath($ROOTPATH);
    return 1;
}

sub getMMSXML{
    return <<__MMSSTRING;
<?xml version="1.0" encoding="UTF-8"?>
<eventlist xmlns="http://api.clickandbuy.com/webservices/pay_1_1_0/"> 
    <signature>7162593DFE1AE821DBDEB02C850256F7696D0472</signature>
    <payEvent>
        <merchantID>123456789</merchantID>
        <projectID>1</projectID>
        <eventID>123456789</eventID>
        <creationDateTime>2013-02-15T09:48:04.657Z</creationDateTime>
        <transactionID>123987456</transactionID>
        <externalID>50FFE7A2-8FF8-9E24-95C6-AC1532012147</externalID>
        <crn>1763523926</crn>
        <transactionAmount>
            <amount>700</amount>
            <currency>EUR</currency>
        </transactionAmount>
        <merchantAmount>
            <amount>700</amount>
            <currency>EUR</currency>
        </merchantAmount>
        <newState>CREATED</newState>
    </payEvent>
    <payEvent>
        <merchantID>123456789</merchantID>
        <projectID>1</projectID>
        <eventID>123456789</eventID>
        <creationDateTime>2013-02-15T09:48:05.590Z</creationDateTime>
        <transactionID>123987456</transactionID>
        <externalID>50FFE7A2-8FF8-9E24-95C6-AC1532012147</externalID>
        <crn>1763523926</crn>
        <transactionAmount>
            <amount>700</amount>
            <currency>EUR</currency>
        </transactionAmount>
        <merchantAmount>
            <amount>700</amount>
            <currency>EUR</currency>
        </merchantAmount>
        <oldState>CREATED</oldState>
        <newState>SUCCESS</newState>
    </payEvent>
</eventlist>
__MMSSTRING
}

sub Init {
    return 1 if ExistsObjectByPath($ROOTPATH) && $ENV{'SKIP_CLEANUP'};
    Cleanup();
    LoadRootObject()->insertChild( 'Object', { Alias => 'Test' } );
    ImportObjects( 'ImportOrder.xml', $ROOTPATH );
    return 1;
}

RunScript( Sub => \&Main );

1;