/*
 * @copyright   © Copyright 2006-2012, epages GmbH, All Rights Reserved.
 *
 * @module      de_epages.design.inc.editorMenu
 */
jQuery.plugin('de_epages.design.inc.editorMenu', {
  plugin: ['jQuery.storage', 'jQuery.tmpl', 'ep.dict'],
  tmpl: ['de_epages.design.inc.editormenu'],
  dict: ['de_epages.design.inc.editormenu'],
  DOM: true
}, function ($) {
  $.extend($.scope("de_epages.design.inc"), {
    editorMenu: {
      init: function (options) {
        var o, renderedTemplate, storage, $list, $message, $opener, $selector;
        var cssClassMap = {
            Content: 'ico_l_contentpreview',
            StyleWizard: 'ico_l_stylewizard',
            StyleEditor: 'ico_l_styleeditor'
        };
        o = $.extend({
          // defaults
          editor: 'Content',
          customiseDesign: 'NotAllowed'
        }, options);
        // render template
        renderedTemplate = $.tmpl('de_epages.design.inc.editormenu', {
          activeEditorClass: cssClassMap[o.editor],
          customiseDesign: o.customiseDesign
        }).dictParse('de_epages.design.inc.editormenu', true);
        // get storage informations about already closed tooltips
        storage = $.localStorage('EditorTooltipMessage') || false;
        // cache often used DOM elements
        $message = renderedTemplate.find('#editorSelectorMessage');
        $selector = renderedTemplate.find('#editorSelector');
        $list = renderedTemplate.find('#editorSelectorList');
        $opener = renderedTemplate.find('#openEditorSelector');
        // set current editor to acitve in the list
        $list.find('.Open' + o.editor).addClass('active');
        // save closed tooltips in local storage on close
        $message.on('close', function () {
            $.localStorage('EditorTooltipMessage', true);
            $(this).addClass('HideElement');
        });
        // simulate a delayed hover status with *jQuery.delay*
        $selector.on('mouseenter', function() {
          $(this).clearQueue();
          // only hide not close the tooltip on hover
          $message.addClass('HideElement');
          $selector.addClass('open').css('height', (o.customiseDesign === 'Allowed' ? 139 : 93) + 'px');
        }).on('mouseleave', function () {
          $(this)
            .delay(250)
            .queue(function (next) {
              $selector.removeClass('open').css('height', '');
              next();
            });
        });
        // trigger close event for tooltip
        $message.find('#CloseMessage').on('click', function () {
          $message.trigger('close');
        });
        // set click events for location change
        $list.find('#editorSelectorContentEditor').on('click', function () {
          location.href = '?ViewAction=MBO-ViewContent&ObjectID=' + epages.vars.CategoriesID;
        });
        $list.find('#editorSelectorQuickDesign').on('click', function () {
          location.href = '?ViewAction=MBO-ViewStyleWizard&ObjectID=' + epages.vars.StyleId;
        });
        if (o.customiseDesign === 'Allowed') {
            $list.find('#editorSelectorAdvancedDesign').on('click', function () {
              location.href = '?ViewAction=MBO-ViewStyleEditor&ObjectID=' + epages.vars.StyleId;
            });
        }
        // if the tooltip has been close do not show it again
        if (storage === true) {
            $message.addClass('HideElement');
        }

        if (o.editor === 'Content') {
            $('#LeftSidebar').find('.CloseButton').on('click', function () {
              renderedTemplate.addClass('left-margin');
            });
            $('#LeftSidebar').find('.MinimizeNode').on('click', function () {
              renderedTemplate.removeClass('left-margin');
            });
        }
        // insert the template into the DOM
        $('.ContentSpacer').prepend(renderedTemplate);
      }
    }
  });
});
