#!perl -w
use Test::More tests => 2;
use strict;
use File::Temp qw( tempdir );

use DE_EPAGES::Core::API::File qw(CreateDirectory WriteFile DeleteDirectory);
use DE_EPAGES::Core::API::Script qw(RunScript);
use DE_EPAGES::Installer::API::EpagesJ qw(GetEpagesJBuild GetEpagesJVersion);

sub Main {
    my $TmpDir = tempdir();

    my $Content = <<HERE
epagesj-version: 6.15.3
build: 74
timestamp: 2013-03-12_00-38-45
revision: 18f43b20234aa2f6a810380a64c897c1a9119bb2
ci-url: http://epages7.intern.epages.de:8080/job/ePagesJ%20release/74/
HERE
;

    my $JDir = "$TmpDir/j";
    CreateDirectory("$JDir/webapps");
    WriteFile("$JDir/webapps/epagesj.version", \$Content);

    my $Build = GetEpagesJBuild($JDir);
    my $Version = GetEpagesJVersion($JDir);

    my $ExpectedBuild = '74';
    my $ExpectedVersion = '6.15.3';

    ok( $ExpectedBuild eq $Build, "GetEpagesJBuild: $ExpectedBuild eq $Build" );
    ok( $ExpectedVersion eq $Version, "GetEpagesJVersion: $ExpectedVersion eq $Version" );

    DeleteDirectory($TmpDir, {recursive => 1});
}

RunScript( Sub => \&Main );

1;
