use Test::More tests => 12;

use strict;
use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Database::API::Connection qw ( GetTestSite RunOnStore );
use DE_EPAGES::Newsletter::API::Constants qw (
    NEWSLETTER_ADDRESSEE_SUBSCRIBED
    NEWSLETTER_ADDRESSEE_UNSUBSCRIBED
    NEWSLETTER_ADDRESSEE_REQUEST_UNSUBSCRIBE
    NEWSLETTER_ADDRESSEE_REQUEST_SUBSCRIBE
);
use DE_EPAGES::Object::API::Factory qw ( LoadRootObject );

sub Init {
    Cleanup();
    LoadRootObject()->insertChild('Object', { Alias => 'Test' });
}

sub Cleanup {
    my $System = LoadRootObject();
    $System->child('Test')->delete if $System->existsChild('Test');
}

sub Main {
    my $Test = LoadRootObject()->child('Test');
    my $NewsletterCampaign = $Test->insertChild('NewsletterCampaign', {
        Alias => 'Campaign1',
        Name => 'Daily News',
    });
    is( $NewsletterCampaign->alias, 'Campaign1', 'create NewsletterCampaign' );


    is( 0, $NewsletterCampaign->get('AddresseeCount'), 'no addressee yet' );
    my $Addressee = $NewsletterCampaign->addAddressee({
        'EMail' => 'test@example.com', ## no critic qw(RequireInterpolationOfMetachars)
        'Name'  => 'Tom Tester',
    });
    is( $Addressee->get('EMail'), 'test@example.com', 'Addressee email' );
    is( $Addressee->get('Name'), 'Tom Tester', 'Addressee name' );
    is( $Addressee->get('Unsubscribed'), NEWSLETTER_ADDRESSEE_SUBSCRIBED, 'not Unsubscribed' );
    is( 1, $NewsletterCampaign->get('AddresseeCount'), 'now we have 1 addressee' );
    is( 1, scalar @{ $NewsletterCampaign->get('SubscribedAddressees') }, 'subscribed by default' );

    $Addressee->set({'Unsubscribed' => NEWSLETTER_ADDRESSEE_REQUEST_SUBSCRIBE});
    is( 0, scalar @{ $NewsletterCampaign->get('SubscribedAddressees') }, 'subscribed, but not confirmed yet' );

    $Addressee->set({'Unsubscribed' => NEWSLETTER_ADDRESSEE_SUBSCRIBED});
    is( 1, scalar @{ $NewsletterCampaign->get('SubscribedAddressees') }, 'addressee is confirmed' );

    $Addressee->set({'Unsubscribed' => NEWSLETTER_ADDRESSEE_REQUEST_UNSUBSCRIBE});
    is( 1, scalar @{ $NewsletterCampaign->get('SubscribedAddressees') }, 'not yet unsubscribed' );

    $Addressee->set({'Unsubscribed' => NEWSLETTER_ADDRESSEE_UNSUBSCRIBED});
    is( 0, scalar @{ $NewsletterCampaign->get('SubscribedAddressees') }, 'now the addresse is unsubscribed' );
    is( 1, $NewsletterCampaign->get('AddresseeCount'), 'still 1 addresses' );
}

RunScript( Debug => 1, Sub => sub {
    RunOnStore( Store => GetTestSite(), Sub => sub {
        Init();
        Main();
        Cleanup();
    });
});

1;