use strict;
use Test::Simple tests => 5;
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Object::API::Factory qw( ExistsObjectByPath LoadObjectByPath LoadRootObject
                                        LoadClassByAlias ExistsClassByAlias );
use DE_EPAGES::Database::API::Connection qw( ConnectTestSite DisconnectSite );

my $ATTRIBUTE_PACKAGE = 'DE_EPAGES::Object::API::Attributes::MoneyCurrencyAttribute';
my $ROOTPATH = '/Test';

sub Main {
    ConnectTestSite();

    # create test classes
    ok( Init(), 'initialization' );

    my $TestObject = LoadObjectByPath( $ROOTPATH );
    my $Object = LoadClassByAlias('C1')->insertObject({
        Parent => $TestObject,
        Alias => 'C1O1'
    } );
    my $ObjectID = $Object->id;
    ok( $ObjectID, 'InsertObject' );

    $Object->set({'AccountBalance', { EUR => 1_000.0, USD => undef }});
    ok( $Object->get('AccountBalance' )->{EUR} eq '1000', 'EUR amount 1000' );
    ok( $Object->get('AccountBalance' )->{USD} eq undef, 'USD amount undef' );

    ok( Cleanup(), "cleanup" );

    DisconnectSite();
}

sub Cleanup {
    if( ExistsClassByAlias( 'C1' ) ) {
        my $Class = LoadClassByAlias('C1');
        $Class->deleteAttribute('AccountBalance');
        $Class->delete;
    }
    if( ExistsObjectByPath( $ROOTPATH ) ) {
        LoadObjectByPath( $ROOTPATH )->delete;
    }
    return 1;
}

sub Init {
    Cleanup();
    my $ClassObject = LoadClassByAlias( 'Object' );
    my $Class1 = $ClassObject->insertSubClass({ Alias => 'C1' });
    $Class1->insertAttribute({ Alias => 'AccountBalance', Type => 'MoneyAttribute', Package => $ATTRIBUTE_PACKAGE });

    $ClassObject->insertObject( { Alias => 'Test', Parent => LoadRootObject() } );
    return 1;
}

RunScript(Sub=>\&Main, Debug=>1);