#========================================================================================
# package      DE_EPAGES::RemoteSearch::t::ProductBatchProcessFlagIndexHandler
# state        private
#========================================================================================
package DE_EPAGES::RemoteSearch::t::ProductBatchProcessFlagIndexHandler;
use base Test::Class;


use DE_EPAGES::Core::API::Error qw ( ExistsError GetError );
use DE_EPAGES::Core::API::File qw ( RunOnDirectory );
use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Database::API::Connection qw ( GetTestSite RunOnStore );
use DE_EPAGES::Object::API::Factory qw (
    ExistsObjectByPath
    JoinObjectPath
    LoadObjectByPath
    LoadRootObject
);
use DE_EPAGES::Object::API::XML::ObjectImportHandler qw ( ImportObjects );
use DE_EPAGES::RemoteSearch::API::IndexStatus qw (
    INDEXSTATUS_DIRTY
    INDEXSTATUS_UNITIALIZED
);
use DE_EPAGES::RemoteSearch::API::Object::ProductBatchProcessFlagIndexHandler;
use DE_EPAGES::RemoteSearch::API::RemoteSearchImpl qw (
    DropAllSearchIndexes
    GetOrCreateSearchIndex
);
use DE_EPAGES::RemoteSearch::API::DTO::UpdateItem;
use File::Basename;
use Test::More;

use strict;
use warnings;

my $ROOTALIAS    = 'Test';
my $ROOTPATH     = JoinObjectPath( [ '', $ROOTALIAS ] );
my $TESTSHOPPATH = JoinObjectPath( [ '', $ROOTALIAS, 'TestShopRemoteSearch' ] );

sub init : Test(startup) {
    my $self = shift;
    return 1 if ExistsObjectByPath($ROOTPATH) && $ENV{'SKIP_CLEANUP'};
    $self->cleanup();
    LoadRootObject()->insertChild( 'Object', { Alias => $ROOTALIAS } );
    ImportObjects( 'import.xml', $ROOTPATH );
    return 1;
}

sub cleanup : Test(shutdown) {
    my $self = shift;
    return 1 if $ENV{'SKIP_CLEANUP'};
    DropAllSearchIndexes( LoadObjectByPath($TESTSHOPPATH) ) if ( ExistsObjectByPath($TESTSHOPPATH) );
    LoadObjectByPath($ROOTPATH)->delete if ExistsObjectByPath($ROOTPATH);
}

sub setUp : Test(setup) {
    my $self = shift;
    $self->{Shop}        = LoadObjectByPath($TESTSHOPPATH);
    GetOrCreateSearchIndex( $self->shop );
}

sub testRunBatchProcess : Test(no_plan) {
    my $self = shift;

    # precondition
    is($self->shop->get('RemoteProductSearchIndex')->get('IndexStatusString'), INDEXSTATUS_UNITIALIZED, 'unitialized (after initial create)');

    # test
    my $Handler   = DE_EPAGES::RemoteSearch::API::Object::ProductBatchProcessFlagIndexHandler->new();
    my $aProducts = $self->shop->get('Products');
    $Handler->addItem(DE_EPAGES::RemoteSearch::API::DTO::UpdateItem->new(product => $_)) foreach (@{$aProducts});
    $Handler->processItemList();

    # postcondition
    is($self->shop->get('RemoteProductSearchIndex')->get('IndexStatusString'), INDEXSTATUS_DIRTY, 'dirty (after batch operation)');
}

sub shop {
    return shift->{Shop};
}

####### Main ############
RunScript(
    Sub => sub {
        RunOnDirectory(
            dirname(__FILE__),
            sub {
                RunOnStore(
                    'Store' => GetTestSite(),
                    'Sub'   => sub {
                        eval {
                            Test::Class->runtests;
                        };
                        if (ExistsError()) {
                            fail(GetError->longMessage);
                        }
                    }
                );
            }
        );
    }
);