#========================================================================================
# package      DE_EPAGES::RemoteSearch::t::RemoteSearchPager
# state        private
#========================================================================================
package DE_EPAGES::RemoteSearch::t::RemoteSearchPager;
use base Test::Class;

use strict;
use warnings;
use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Database::API::Connection qw ( GetTestSite RunOnStore );
use DE_EPAGES::RemoteSearch::API::Object::RemoteSearchPager;
use Test::More;

sub testSimple : Test(no_plan) {
    my $Pager = DE_EPAGES::RemoteSearch::API::Object::RemoteSearchPager->new({'ObjectID'=>1});
    $Pager->set( { 'Items' => [ 1 ] } );
    my $aItems = $Pager->items();
    is(scalar @$aItems, 1, 'testSimple: item list is ok');
    is($aItems->[0]->id, 1, 'testSimple: object loaded correctly');
}

sub testHandleSearchResponse : Test(no_plan) {
    my $Pager = DE_EPAGES::RemoteSearch::API::Object::RemoteSearchPager->new({'ObjectID'=>1});
    $Pager->handleSearchResponse( { 'items' => [ {'filter' => 1 }], 'results' => 5, 'fallbackQuery' => 'fallback' } );
    my $aItems = $Pager->items();
    is(scalar @$aItems, 1, 'testHandleSearchResponse: item list is ok');
    is($Pager->countItems(), 5, 'testHandleSearchResponse: item count is ok');
    is($aItems->[0]->id, 1, 'testHandleSearchResponse: object loaded correctly');
    is($Pager->get('SearchTermNew'), 'fallback', 'testHandleSearchResponse: fallback query inserted');
}

####### Main ############
RunScript(
    Sub => sub {
        RunOnStore(
            'Store' => GetTestSite(),
            'Sub'   => sub {
                Test::Class->runtests;
            }
        );
    },
    Debug => 1,
);
