#========================================================================================
# package      DE_EPAGES::RemoteSearch::t::SearchReplicationToken
# state        private
#========================================================================================
package DE_EPAGES::RemoteSearch::t::SearchReplicationToken;
use base Test::Class;

use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Database::API::Connection qw ( GetCurrentDBHandle GetTestSite RunOnStore );
use DE_EPAGES::RemoteSearch::API::Table::SearchReplicationToken qw (
    ExistsSearchReplicationToken
    GetAllPKeySearchReplicationTokens
    IncrementAndGetReplicationToken
);
use Test::More;

use strict;

sub TestIncrementAndGetReplicationToken : Test(2) {
    my $self = shift;

    # this can fail, if we have other activity on the testsite... but should be fairly seldom
    my $Token1 = IncrementAndGetReplicationToken();
    my $Token2 = IncrementAndGetReplicationToken();

    is( $Token1 + 1, $Token2, 'Increment and get token' );
    is( scalar @{GetAllPKeySearchReplicationTokens()}, 1, 'automatic cleanup' );
}

sub TestIncrementAndGetReplicationTokenInTransaction : Test(3) {
    my $self = shift;

    GetCurrentDBHandle()->transaction( sub {
        # this can fail, if we have other activity on the testsite... but should be fairly seldom
        my $Token1 = IncrementAndGetReplicationToken();
        my $Token2 = IncrementAndGetReplicationToken();

        is( $Token1 + 1, $Token2, 'Increment and get token' );
        ok( ExistsSearchReplicationToken({'SearchReplicationTokenID' => $Token1}), 'no automatic cleanup' );
        ok( ExistsSearchReplicationToken({'SearchReplicationTokenID' => $Token2}), 'no automatic cleanup' );
    });
}

RunScript(
    Sub => sub {
        RunOnStore(
            'Store' => GetTestSite(),
            'Sub'   => sub {
                Test::Class->runtests;
            }
        );
    }
);
