#========================================================================================
# package DE_EPAGES::RemoteSearch::t::ViewCategoryWithRemoteSearch
# state private
#----------------------------------------------------------------------------------------
# description Tests View on a category with FakeRequest
#              Needs a Store with DemoShop
#========================================================================================
package DE_EPAGES::RemoteSearch::t::ViewCategoryWithRemoteSearch;
use base Test::Class;

use strict;

use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Database::API::Connection qw ( GetTestSite RunOnStore );
use DE_EPAGES::Object::API::Factory qw (
  ExistsObjectByPath
  LoadObjectByPath
  LoadRootObject
);
use DE_EPAGES::Shop::API::Url qw ( BuildShopUrl );
use DE_EPAGES::WebInterface::API::FakeRequest;
use JSON;
use Test::More;

sub setUp : Test(startup) {
    my $self = shift;
    plan skip_all => 'no demoshop installed'     unless ( ExistsObjectByPath('/Shops/DemoShop') );
    plan skip all => 'remote search not enabled' unless ( LoadRootObject->get('RemoteSearchEnabled') );

    $self->shop( LoadObjectByPath('/Shops/DemoShop') );
    plan skip_all => 'DemoShop did not initialize remotesearch'
      unless ( defined $self->shop->get('RemoteProductSearchIndex')
        && $self->shop->get('RemoteProductSearchIndex')->usableAtStorefront );

    plan skip_all => 'DemoShop does not use auto-switching from category view to search at depth (2)'
      unless ( $self->shop->get('FacetedSearchStartDepth') == 2);
}

sub TestView : Test(no_plan) {
    my $self        = shift;
    my $FakeRequest = DE_EPAGES::WebInterface::API::FakeRequest->new;
    my $URL = BuildShopUrl( $self->shop->child('Categories')->child('Tents')->child('IndividualTents'),
        { 'ViewAction' => 'View'}, {} );
    my $Response = $FakeRequest->get($URL);

    ok( $Response->is_success, 'ViewAction with facets' ) or diag( $Response->status_line );
    ok( $Response->decoded_content() =~ m/FacetName/, 'Found facets with searchstring' );
}

sub shop {
    my $self = shift;
    my ($shop) = @_;
    return $self->{'shop'} unless ( defined($shop) );
    $self->{'shop'} = $shop;
}

RunScript(
    Sub => sub {
        RunOnStore(
            'Store' => GetTestSite(),
            'Sub'   => sub {
                Test::Class->runtests;
            }
        );
    }
);
